Tiny test build — Python documentation

# Tiny test build

The complete Sphinx-Gallery project is automatically documented for every module. Examples here.

## Sphinx Gallery

`sphinx_gallery`:

`gen_gallery` | Sphinx-Gallery Generator
`backreferences` | Backreferences Generator
`gen_rst` | RST file generator
`py_source_parser` | Parser for python source files
`docs_resolv` | Link resolver objects
`notebook` | Parser for Jupyter notebooks
`downloads` | Utilities for downloadable items
`docs_resolv` | Link resolver objects
`sorting` | Sorters for Sphinx-Gallery (sub)sections

## Examples

This tests that mini-gallery reference labels work: Examples using sphinx_gallery.backreferences.identify_names.

- Gallery of Examples
- Future examples